Crate cosmian_kms_client

Crate cosmian_kms_client 

Re-exports

pub use cosmian_kms_client_utils::reexport::cosmian_kmip;

Modules

kmip_0
Messages and types common to all KMIP versions.
kmip_1_4
kmip_2_1
reexport

Macros

kms_client_bail
Return early with an error if a condition is not satisfied.
kms_client_error
Construct a server error from a string.

Structs

ExportObjectParams
GmailApiConf
The configuration that is used by the google command to perform actions over Gmail API.
KmsClient
A struct implementing some of the 50+ operations a KMIP client should implement: https://www.oasis-open.org/committees/tc_home.php?wg_abbrev=kmip
KmsClientConfig

Enums

KmsClientError

Functions

batch_export_objects
Export a batch of Objects from the KMS
export_object
Export an Object from the KMS
pad_be_bytes
read_bytes_from_file
Read all bytes from a file
read_bytes_from_files_to_bulk
Read all bytes from multiple files and serialize them into a unique vector using LEB128 serialization (bulk mode)
read_from_json_file
Read an object T from a JSON file
read_object_from_json_ttlv_bytes
Read an object from KMIP JSON TTLV bytes slice
read_object_from_json_ttlv_file
Read an object from a KMIP JSON TTLV file
write_bulk_decrypted_data
Write bulk decrypted data
write_bulk_encrypted_data
Write bulk encrypted data
write_bytes_to_file
Write all bytes to a file
write_json_object_to_file
Write a JSON object to a file
write_kmip_object_to_file
Writes a KMIP Object to a JSON TTLV in a file.
write_single_decrypted_data
Write the decrypted data to a file
write_single_encrypted_data
Write the encrypted data to a file

Type Aliases

KmsClientResult