Re-exports
pub use cosmian_kms_client_utils::reexport::cosmian_kmip;
Modules
Macros
- kms_
client_ bail - Return early with an error if a condition is not satisfied.
- kms_
client_ error - Construct a server error from a string.
Structs
- Export
Object Params - Gmail
ApiConf - The configuration that is used by the google command to perform actions over Gmail API.
- KmsClient
- A struct implementing some of the 50+ operations a KMIP client should implement: https://www.oasis-open.org/committees/tc_home.php?wg_abbrev=kmip
- KmsClient
Config
Enums
Functions
- batch_
export_ objects - Export a batch of Objects from the KMS
- export_
object - Export an Object from the KMS
- pad_
be_ bytes - read_
bytes_ from_ file - Read all bytes from a file
- read_
bytes_ from_ files_ to_ bulk - Read all bytes from multiple files and serialize them into a unique vector using LEB128 serialization (bulk mode)
- read_
from_ json_ file - Read an object T from a JSON file
- read_
object_ from_ json_ ttlv_ bytes - Read an object from KMIP JSON TTLV bytes slice
- read_
object_ from_ json_ ttlv_ file - Read an object from a KMIP JSON TTLV file
- write_
bulk_ decrypted_ data - Write bulk decrypted data
- write_
bulk_ encrypted_ data - Write bulk encrypted data
- write_
bytes_ to_ file - Write all bytes to a file
- write_
json_ object_ to_ file - Write a JSON object to a file
- write_
kmip_ object_ to_ file - Writes a KMIP Object to a JSON TTLV in a file.
- write_
single_ decrypted_ data - Write the decrypted data to a file
- write_
single_ encrypted_ data - Write the encrypted data to a file